Learn R Programming

domino (version 0.3.1)

domino.init: domino.init

Description

Initializes new domino project in current directory. It can also set arbitrary name to the project, even if different from current directory name.

Usage

# inits a project inside current directory, with given name.
# ex. if run in ~/my_project, with "my_name" as a param,
# it will create a Domino project called my-param inside ~/my_project directory.
domino.init("projectName")

Arguments

projectName

Project name for the project that will be created in current working directory.

Examples

Run this code
# NOT RUN {
# in directory ./
domino.init("my-new-project")
# new project with name "my-new-project" is initialized inside current directory.
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab