Learn R Programming

domino (version 0.3.1)

domino.run: domino.run

Description

Runs your project on Domino servers with given parameters.

Usage

domino.run(..., publishApiEndpoint=FALSE)

Arguments

...

All the run arguments will be joined together using space character. Ex. domino.run("main.py", "-xvz", "my-file1.csv")

publishApiEndpoint

Whether or not to republish the project's API endpoint at the end of the run.

Examples

Run this code
# NOT RUN {
my_data <- 4
domino.run("main.R","1","my-file1.csv", my_data)
#=> Runs "domino main.R 1 my-file1.csv 4"
# }

Run the code above in your browser using DataLab