powered by
Runs your project on Domino servers with given parameters.
domino.run(..., publishApiEndpoint=FALSE)
All the run arguments will be joined together using space character. Ex. domino.run("main.py", "-xvz", "my-file1.csv")
domino.run("main.py", "-xvz", "my-file1.csv")
Whether or not to republish the project's API endpoint at the end of the run.
# NOT RUN { my_data <- 4 domino.run("main.R","1","my-file1.csv", my_data) #=> Runs "domino main.R 1 my-file1.csv 4" # }
Run the code above in your browser using DataLab